<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);
session_start();

if (!isset($_SESSION['id'])) {
    header("Location: index.php");
    exit;
}

include 'db.php';


$admin_id = $_SESSION['id'];
$query = "SELECT admin_type FROM admin WHERE id = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $admin_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $admin_type = $row['admin_type']; // Store admin_type in a variable
} else {
    $admin_type = null; // Default if not found
}

// Initialize user_type
$user_type = isset($_POST['user_type']) ? $_POST['user_type'] : 'all'; // Default to 'all'

// Prepare the SQL query based on the selected user type
if ($user_type == 'direct_join') {
    $user_stmt = $conn->prepare("SELECT id, name, phone, reference_number, my_number, created_at, total_balance, approved FROM MLM_users WHERE reference_number IS NULL");
} elseif ($user_type == 'reference_user') {
    $user_stmt = $conn->prepare("SELECT id, name, phone, reference_number, my_number, created_at, total_balance, approved FROM MLM_users WHERE reference_number IS NOT NULL");
} else {
    // Default case for All Users
    $user_stmt = $conn->prepare("SELECT id, name, phone, reference_number, my_number, created_at, total_balance, approved FROM MLM_users");
}

// Execute the query
$user_stmt->execute();
$user_result = $user_stmt->get_result();

// Fetch all users
$users = $user_result->fetch_all(MYSQLI_ASSOC);
$user_stmt->close();

// Function to log errors (Optional, can be used as needed)
function logError($message)
{
    error_log($message, 3, "error_log.log");
}





// Function to check if the user is authorized
function isAuthorized($conn, $user_id)
{
    $stmt = $conn->prepare("SELECT admin_type FROM admin WHERE id = ?");
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $stmt->bind_result($admin_type);
    $stmt->fetch();
    $stmt->close();

    return $admin_type == 1;
}

// Function to insert wallet transaction
function insertWalletTransaction($conn, $user_id, $amount, $description)
{
    $stmt = $conn->prepare("INSERT INTO wallet_transactions (user_id, amount, description, created_at, wallet_type) VALUES (?, ?, ?, NOW(), 'add')");
    $stmt->bind_param("ids", $user_id, $amount, $description);

    if (!$stmt->execute()) {
        logError("Failed to insert transaction for user ID $user_id: " . $stmt->error);
    }

    $stmt->close();
}

// Function to generate a unique my_number
function generateMyNumber($conn)
{
    do {
        $random_number = rand(1000, 9999);
        $my_number = "MLM@" . $random_number;

        // Check for uniqueness
        $stmt = $conn->prepare("SELECT COUNT(*) FROM MLM_users WHERE my_number = ?");
        $stmt->bind_param("s", $my_number);
        $stmt->execute();
        $stmt->bind_result($count);
        $stmt->fetch();
        $stmt->close();
    } while ($count > 0);

    return $my_number;
}

// Function to distribute bonuses
function distributeBonuses($conn, $my_number, $reference_number, $user_id)
{
    $bonus_amount_25 = 200 * 0.25; // 25% of 200
    $bonus_amount_5 = 200 * 0.05;  // 5% of 200

    // 25% bonus distribution: Find users whose my_number matches the approved user's reference_number
    $stmt = $conn->prepare("SELECT id FROM MLM_users WHERE my_number = ? AND approved = 1");
    $stmt->bind_param("s", $reference_number);
    $stmt->execute();
    $result = $stmt->get_result();

    while ($bonus_user_25 = $result->fetch_assoc()) {
        $bonus_user_id_25 = $bonus_user_25['id'];

        // Update balance for the 25% bonus
        $update_balance_stmt_25 = $conn->prepare("UPDATE MLM_users SET total_balance = total_balance + ? WHERE id = ?");
        $update_balance_stmt_25->bind_param("di", $bonus_amount_25, $bonus_user_id_25);
        $update_balance_stmt_25->execute();
        $update_balance_stmt_25->close();

        // Insert transaction for 25% bonus
        insertWalletTransaction($conn, $bonus_user_id_25, $bonus_amount_25, "25% bonus for referencing $my_number");

        // Distribute 5% bonuses recursively
        distributeFivePercentBonus($conn, $bonus_user_id_25, $bonus_amount_5);
    }
}

// Recursive function to distribute 5% bonuses
function distributeFivePercentBonus($conn, $bonus_user_id_25, $bonus_amount_5)
{
    // Fetch the reference_number of the user who received the 25% bonus
    $stmt = $conn->prepare("SELECT reference_number FROM MLM_users WHERE id = ?");
    $stmt->bind_param("i", $bonus_user_id_25);
    $stmt->execute();
    $stmt->bind_result($reference_number);
    $stmt->fetch();
    $stmt->close();

    // Stop if no reference_number is found
    if (empty($reference_number)) {
        return;
    }

    // Fetch users whose my_number matches the reference_number and who are approved
    $stmt = $conn->prepare("SELECT id FROM MLM_users WHERE my_number = ? AND approved = 1");
    $stmt->bind_param("s", $reference_number);
    $stmt->execute();
    $result = $stmt->get_result();

    while ($bonus_user_5 = $result->fetch_assoc()) {
        $bonus_user_id_5 = $bonus_user_5['id'];

        // Update balance for the 5% bonus
        $update_balance_stmt_5 = $conn->prepare("UPDATE MLM_users SET total_balance = total_balance + ? WHERE id = ?");
        $update_balance_stmt_5->bind_param("di", $bonus_amount_5, $bonus_user_id_5);
        $update_balance_stmt_5->execute();
        $update_balance_stmt_5->close();

        // Insert transaction for 5% bonus
        insertWalletTransaction($conn, $bonus_user_id_5, $bonus_amount_5, "5% bonus for referencing $bonus_user_id_25");

        // Recursively distribute the 5% bonus further
        distributeFivePercentBonus($conn, $bonus_user_id_5, $bonus_amount_5);
    }
}

function approveUser($conn, $user_id, $referral_code)
{
    // Check if the referral code exists in refer_table with status 'false'
    $checkReferral = $conn->prepare("SELECT new_id FROM refer_table WHERE ref_id = ? AND status = 'false'");
    if ($checkReferral) {
        $checkReferral->bind_param("s", $referral_code);
        $checkReferral->execute();
        $checkReferral->store_result();

        if ($checkReferral->num_rows > 0) {
            // Referral code exists with status 'false'
            $checkReferral->bind_result($refer_id);
            $checkReferral->fetch();
        } else {
            // Referral code does not exist, set refer_id to 0 or another default value
            $refer_id = 0;
        }
        $checkReferral->close();
    } else {
        $message = 'Failed to prepare statement for referral code check: ' . $conn->error;
        return;
    }

    // Fetch user details
    $stmt = $conn->prepare("SELECT my_number, reference_number FROM MLM_users WHERE id = ?");
    if ($stmt) {
        $stmt->bind_param("i", $user_id);
        $stmt->execute();
        $stmt->bind_result($my_number, $reference_number);
        $stmt->fetch();
        $stmt->close();

        // If user has no my_number, generate one
        if (empty($my_number)) {
            $my_number = generateMyNumber($conn);
        }

        // Fetch the tree_head from the refer_table using reference_number
        $treeHeadQuery = $conn->prepare("SELECT new_code AS tree_head FROM refer_table WHERE refer_id = ?");
        if ($treeHeadQuery) {
            $treeHeadQuery->bind_param("s", $reference_number);
            $treeHeadQuery->execute();
            $treeHeadQuery->bind_result($tree_head);
            $treeHeadQuery->fetch();
            $treeHeadQuery->close();
        } else {
            $tree_head = "0"; // Default tree_head if no matching record is found
        }

        // Update user approval status, tree_head, and my_number
        $stmt = $conn->prepare("UPDATE MLM_users SET approved = 1, tree_head = ?, my_number = ? WHERE id = ?");
        if ($stmt) {
            $stmt->bind_param("ssi", $tree_head, $my_number, $user_id);
            if ($stmt->execute()) {
                // Now insert into refer_table 4 times
                for ($i = 0; $i < 4; $i++) {
                    $child = $conn->prepare("INSERT INTO refer_table (new_id, new_code, refer_id) VALUES (?, ?, ?)");
                    if ($child) {
                        // Use the user's ID and my_number in the insertion
                        $child->bind_param("iss", $user_id, $my_number, $referral_code);  // "i" for user_id (int), "s" for my_number (string)

                        if ($child->execute()) {
                            $message = 'Registration successful! Please log in.';
                        } else {
                            $message = 'Failed to insert into refer_table: ' . $child->error;
                            break; // Stop if any insert fails
                        }
                        $child->close();
                    } else {
                        $message = 'Failed to prepare statement for refer_table insertion.';
                        break; // Stop if the statement preparation fails
                    }
                }
            } else {
                $message = 'Failed to update MLM_user: ' . $stmt->error;
            }
            $stmt->close();
        } else {
            $message = 'Failed to prepare statement for MLM_user update.';
        }
    } else {
        $message = 'Failed to prepare statement for user details fetch.';
    }


    echo $message;
    // Distribute bonuses
    // distributeBonuses($conn, $my_number, $referral_code, $user_id);
}



// Handle approval action
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['approve_user_id'])) {
    $user_id = $_POST['approve_user_id'];
    $reference_number = $_POST['reference_number'];
    $admin_id = $_SESSION['id']; // Assuming the logged-in admin's ID is stored in session

    if (isAuthorized($conn, $admin_id)) {
        approveUser($conn, $user_id,$reference_number);
    } else {
        $unauthorized_user_id = $user_id; // Store the unauthorized attempt
        logError("Unauthorized attempt to approve user ID: " . $unauthorized_user_id);
    }
}

// Get all users details
$user_stmt = $conn->prepare("SELECT id, name, phone, reference_number, my_number, created_at, total_balance, approved FROM MLM_users");
$user_stmt->execute();
$user_result = $user_stmt->get_result();

// Fetch all users
$users = $user_result->fetch_all(MYSQLI_ASSOC);
$user_stmt->close();
?>


<?php include 'header.php'; ?>

<div class="dashboard-main-body">
    <div class="d-flex flex-wrap align-items-center justify-content-between gap-3 mb-24">
        <h6 class="fw-semibold mb-0">User Management</h6>
        <ul class="d-flex align-items-center gap-2">
            <li class="fw-medium">
                <a href="index.php" class="d-flex align-items-center gap-1 hover-text-primary">
                    <iconify-icon icon="solar:home-smile-angle-outline" class="icon text-lg"></iconify-icon>
                    All Users
                </a>
            </li>
            <li>-</li>
            <li class="fw-medium">User List</li>
        </ul>
    </div>

    <div class="card basic-data-table">

        <div class="card-body">

            <div class="d-flex flex-wrap align-items-center justify-content-between">
                <h6 class="text-lg mb-0">All Users</h6>

            </div>
            <br>
            <div style="overflow-x: auto; white-space: nowrap;">
                <table class="table bordered-table mb-0" id="dataTable" data-page-length='10' style="min-width: 800px;">
                    <thead>
                        <tr>
                            <th scope="col">S.L</th>
                            <th scope="col">ID</th>
                            <th scope="col">Name</th>
                            <th scope="col">Phone</th>
                            <th scope="col">Reference Number</th>
                            <th scope="col">My Number</th>
                            <th scope="col">Created At</th>
                            <th scope="col">Approved</th>
                            <?php if ($admin_type == 1): // Show "Others" column only for admin type 1 ?>
                                <th scope="col">Others</th>
                            <?php endif; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($users as $index => $user): ?>
                            <tr>
                                <td><?php echo $index + 1; ?></td>
                                <td><?php echo htmlspecialchars($user['id']); ?></td>
                                <td><?php echo htmlspecialchars($user['name']); ?></td>
                                <td><?php echo htmlspecialchars($user['phone']); ?></td>
                                <td><?php echo htmlspecialchars($user['reference_number']); ?></td>
                                <td><?php echo htmlspecialchars($user['my_number']); ?></td>
                                <td><?php echo htmlspecialchars($user['created_at']); ?></td>
                                <td>
                                    <?php if (!$user['approved']): ?>
                                        <button class="btn btn-primary" data-toggle="modal"
                                            data-target="#approveModal-<?php echo $user['id']; ?>">Approve</button>
                                    <?php else: ?>
                                        <span class="text-success">Approved</span>
                                    <?php endif; ?>
                                </td>
                                <?php if ($admin_type == 1): // Show actions only for admin type 1 ?>
                                    <td>
                                        <a href="view-user.php?user_id=<?php echo $user['id']; ?>"
                                            class="w-32-px h-32-px bg-primary-light text-primary-600 rounded-circle d-inline-flex align-items-center justify-content-center">
                                            <iconify-icon icon="iconamoon:eye-light"></iconify-icon>
                                        </a>
                                        <a href="user-edit.php?user_id=<?php echo $user['id']; ?>"
                                            class="w-32-px h-32-px bg-success-focus text-success-main rounded-circle d-inline-flex align-items-center justify-content-center">
                                            <iconify-icon icon="lucide:edit"></iconify-icon>
                                        </a>
                                        <a href="user-report.php?user_id=<?php echo $user['id']; ?>"
                                            class="w-32-px h-32-px bg-danger-focus text-danger-main rounded-circle d-inline-flex align-items-center justify-content-center">
                                            <iconify-icon icon="mdi:repost"></iconify-icon>
                                        </a>
                                    </td>
                                <?php endif; ?>
                            </tr>

                            <!-- Approval Confirmation Modal -->
                            <div class="modal fade" id="approveModal-<?php echo $user['id']; ?>" tabindex="-1" role="dialog"
                                aria-labelledby="approveModalLabel-<?php echo $user['id']; ?>" aria-hidden="true">
                                <div class="modal-dialog" role="document">
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h5 class="modal-title" id="approveModalLabel-<?php echo $user['id']; ?>">
                                                Confirm Approval</h5>
                                            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                                <span aria-hidden="true">&times;</span>
                                            </button>
                                        </div>
                                        <div class="modal-body">
                                            <?php
                                            $admin_id = $_SESSION['id'];
                                            $is_authorized = isAuthorized($conn, $admin_id);

                                            if (!$is_authorized): ?>
                                                <div class="alert alert-danger">
                                                    You are not authorized to approve users.
                                                </div>
                                            <?php else: ?>
                                                Are you sure you want to approve this user?
                                            <?php endif; ?>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-secondary"
                                                data-dismiss="modal">Cancel</button>
                                            <?php if (!$is_authorized): ?>
                                                <button type="button" class="btn btn-primary" disabled>You cannot
                                                    approve</button>
                                            <?php else: ?>
                                                <form method="POST" action="">
                                                    <input type="text" name="approve_user_id"
                                                        value="<?php echo $user['id']; ?>">
                                                        <input type="text" name="reference_number"
                                                        value="<?php echo $user['reference_number']; ?>">
                                                    <button type="submit" class="btn btn-primary">Approve</button>
                                                </form>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>

                        <?php endforeach; ?>
                    </tbody>
                </table>

            </div>
        </div>
    </div>
</div>

<?php include 'footer.php';

?>



<link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
<script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>