<?php 
session_start();
include 'db.php'; 
include 'header.php'; 
?>

<div class="section mt-2">
    <div class="card" style="padding: 20px; margin-top: 80px; margin-bottom: 20px;">
        <div style="display: flex; align-items: center; flex-wrap: wrap; gap: 10px; justify-content: space-between; margin-bottom: 20px;">
            <h4 class="mb-2 fw-bold text-lg mb-0">User Transaction History</h4>
            <div style="display: flex; gap: 10px;">
                <input type="text" id="searchInput" class="form-control form-control-sm w-auto" placeholder="Search..." />
                <select id="transactionFilter" class="form-select form-select-sm w-auto bg-base border text-secondary-light">
                    <option value="all">All</option>
                    <option value="add">Add</option>
                    <option value="withdrawal">Withdrawal</option>
                    <option value="pending">Pending</option> <!-- Added pending option -->
                </select>
            </div>
        </div>
        <div class="table-responsive">
            <table class="table ">
                <thead>
                    <tr>
                        <th scope="col">S.L</th>
                        <th scope="col">User ID</th>
                        <th scope="col">User Name</th>
                        <th scope="col">Bank Name</th>
                        <th scope="col">Bank Number</th>
                        <th scope="col">Withdrawal Amount</th>
                        <th scope="col">Branch</th>
                        <th scope="col">Created At</th>
                        <th scope="col">Type</th>
                    </tr>
                </thead>
                <tbody id="transactionTableBody">
                    <?php
                    // Fetching withdrawal transactions from the database
                    $query = "SELECT `id`, `user_id`, `user_name`, `bank_name`, `bank_number`, `withdrawal_amount`, `branch`, `type`, `created_at` FROM `payment_withdrawals`";
                    
                    // Prepare and execute the query
                    $stmt = $conn->prepare($query);
                    if ($stmt) {
                        $stmt->execute();
                        $result = $stmt->get_result();

                        // Initialize serial number counter
                        $sl = 1;

                        // Check if there are any results
                        if ($result->num_rows > 0) {
                            // Loop through each row and display it
                            while ($row = $result->fetch_assoc()) {
                                // Determine classes for the wallet type
                                $wallet_type_class = '';
                                $wallet_type_text_class = '';

                                if ($row['type'] == 'add') {
                                    $wallet_type_class = 'bg-wallet-add';
                                    $wallet_type_text_class = 'text-wallet-add';
                                } elseif ($row['type'] == 'withdrawal') {
                                    $wallet_type_class = 'bg-wallet-withdrawal';
                                    $wallet_type_text_class = 'text-wallet-withdrawal';
                                } elseif ($row['type'] == 'pending') {
                                    $wallet_type_class = 'bg-wallet-pending'; // Add a class for pending
                                    $wallet_type_text_class = 'text-wallet-pending'; // Add a text class for pending
                                }

                                echo "<tr>
                                        <td>{$sl}</td>
                                        <td>{$row['user_id']}</td>
                                        <td>{$row['user_name']}</td>
                                        <td>{$row['bank_name']}</td>
                                        <td>{$row['bank_number']}</td>
                                        <td>₹{$row['withdrawal_amount']}</td>
                                        <td>{$row['branch']}</td>
                                        <td>{$row['created_at']}</td>
                                        <td>
                                            <span class='px-24 py-4 rounded-pill fw-medium text-sm {$wallet_type_class} {$wallet_type_text_class}'>
                                                " . ucfirst($row['type']) . "  <!-- Ensure this matches exactly with the filter options -->
                                            </span>
                                        </td>
                                      </tr>";
                                $sl++;
                            }
                        } else {
                            echo "<tr><td colspan='9' class='text-center text-muted'>No transaction history found.</td></tr>";
                        }

                        // Close the statement
                        $stmt->close();
                    } else {
                        echo "<tr><td colspan='9'>Error preparing the statement.</td></tr>";
                    }

                    // Close the connection
                    $conn->close();
                    ?>
                </tbody>
            </table>
        </div>
        <div id="pagination" class="mt-3 d-flex justify-content-center"></div>
    </div>
</div>

<?php include 'footer.php'; ?>

<script>
    // Filter transactions based on the selected type
    const rows = document.querySelectorAll('#transactionTableBody tr');
    rows.forEach(row => {
        const walletType = row.querySelector('span').textContent.toLowerCase(); // Convert to lowercase for consistency
        row.setAttribute('data-wallet-type', walletType);
    });

    document.getElementById('transactionFilter').addEventListener('change', function() {
        const filterValue = this.value;
        const rows = document.querySelectorAll('#transactionTableBody tr');

        console.log('Selected filter:', filterValue); // Log selected filter

        rows.forEach(row => {
            const walletType = row.getAttribute('data-wallet-type'); // Use data attribute
            console.log('Row wallet type:', walletType); // Log wallet type of each row

            // Show or hide rows based on the selected filter
            if (filterValue === 'all' || filterValue === walletType) {
                row.style.display = '';  // Show the row
                console.log('Showing row for wallet type:', walletType); // Log showing row
            } else {
                row.style.display = 'none';  // Hide the row
                console.log('Hiding row for wallet type:', walletType); // Log hiding row
            }
        });
    });

    // Implement search functionality
    document.getElementById('searchInput').addEventListener('input', function() {
        const searchTerm = this.value.toLowerCase();
        const rows = document.querySelectorAll('#transactionTableBody tr');

        rows.forEach(row => {
            const userId = row.children[1].textContent.toLowerCase();
            const userName = row.children[2].textContent.toLowerCase();
            const bankName = row.children[3].textContent.toLowerCase();
            const createdAt = row.children[7].textContent.toLowerCase();

            // Show or hide rows based on the search term
            if (userId.includes(searchTerm) || userName.includes(searchTerm) || bankName.includes(searchTerm) || createdAt.includes(searchTerm)) {
                row.style.display = '';  // Show the row
            } else {
                row.style.display = 'none';  // Hide the row
            }
        });
    });
</script>

<!-- Styles for Add, Withdrawal, and Pending Statuses -->
<style>
    .text-wallet-add {
        color: #4CAF50 !important; /* Green text color */
    }

    .text-wallet-withdrawal {
        color: #F44336 !important; /* Red text color */
    }

    .text-wallet-pending {
        color: #FFA500 !important; /* Orange text color for pending */
    }

    /* Scrollable table style */
    .table-responsive {
        max-height: 400px; /* Set your desired height */
        overflow-y: auto; /* Enable vertical scrolling */
    }
</style>
